==> ejc-zjkjcost-impl-3.0.0-20220622.021545-5-sources.jar: com/ejianc/business/zjkjcost/manage/bean/BookEntity.java <==
package com.ejianc.business.zjkjcost.manage.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目目标管理责任书
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_manage_book")
public class BookEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目部id
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织Id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="project_location")
    private String projectLocation; // 工程地点
    @TableField(value="built_area")
    private BigDecimal builtArea; // 建筑面积
    @TableField(value="structural_style")
    private String structuralStyle; // 结构形式
    @TableField(value="project_scale")
    private String projectScale; // 项目规模
    @TableField(value="price_method")
    private String priceMethod; // 计价方式
    @TableField(value="quality_standard")
    private String qualityStandard; // 质量标准
    @TableField(value="start_date")
    private Date startDate; // 开工日期
    @TableField(value="end_date")
    private Date endDate; // 竣工日期
    @TableField(value="zb_contract_mny")
    private BigDecimal zbContractMny; // 总包合同额
    @TableField(value="zs_contract_mny")
    private BigDecimal zsContractMny; // 自施合同额
    @TableField(value="other_contract_mny")
    private BigDecimal otherContractMny; // 其他合同额(集成)
    @TableField(value="client")
    private String client; // 委托人
    @TableField(value="trustee")
    private String trustee; // 受托人
    @TableField(value="duration")
    private Integer duration; // 合同总工期
    @TableField(value="contract_category_id")
    private Long contractCategoryId; // 合同类别
    @TableField(value="contract_category_name")
    private String contractCategoryName; // 合同类别名称
    @TableField(value="construction_quality")
    private String constructionQuality; // 工程质量
    @TableField(value="safety_production")
    private String safetyProduction; // 安全生产
    @TableField(value="ic_image")
    private BigDecimal icImage; // IC形象
    @TableField(value="up_payment")
    private BigDecimal upPayment; // 上缴款
    @TableField(value="risk_fund")
    private BigDecimal riskFund; // 风险金预留
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="turnin_base")
    private BigDecimal turninBase; // 上缴基数(不含税收入)
    @TableField(value="responsibility_cost")
    private BigDecimal responsibilityCost; // 责任成本(不含税成本)
    @TableField(value="all_scale")
    private BigDecimal allScale; // 整体上缴比例(B值)
    @TableField(value="amount_paid")
    private BigDecimal amountPaid; // 上缴金额(暂定，随结算金额调整)
    @TableField(value="pre_bid")
    private BigDecimal preBid; // 标前(A值)(承接利润率)
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getProjectLocation() {
        return projectLocation;
    }

    public void setProjectLocation(String projectLocation) {
        this.projectLocation = projectLocation;
    }
    public BigDecimal getBuiltArea() {
        return builtArea;
    }

    public void setBuiltArea(BigDecimal builtArea) {
        this.builtArea = builtArea;
    }
    public String getStructuralStyle() {
        return structuralStyle;
    }

    public void setStructuralStyle(String structuralStyle) {
        this.structuralStyle = structuralStyle;
    }
    public String getProjectScale() {
        return projectScale;
    }

    public void setProjectScale(String projectScale) {
        this.projectScale = projectScale;
    }
    public String getPriceMethod() {
        return priceMethod;
    }

    public void setPriceMethod(String priceMethod) {
        this.priceMethod = priceMethod;
    }
    public String getQualityStandard() {
        return qualityStandard;
    }

    public void setQualityStandard(String qualityStandard) {
        this.qualityStandard = qualityStandard;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public BigDecimal getZbContractMny() {
        return zbContractMny;
    }

    public void setZbContractMny(BigDecimal zbContractMny) {
        this.zbContractMny = zbContractMny;
    }
    public BigDecimal getZsContractMny() {
        return zsContractMny;
    }

    public void setZsContractMny(BigDecimal zsContractMny) {
        this.zsContractMny = zsContractMny;
    }
    public BigDecimal getOtherContractMny() {
        return otherContractMny;
    }

    public void setOtherContractMny(BigDecimal otherContractMny) {
        this.otherContractMny = otherContractMny;
    }
    public String getClient() {
        return client;
    }

    public void setClient(String client) {
        this.client = client;
    }
    public String getTrustee() {
        return trustee;
    }

    public void setTrustee(String trustee) {
        this.trustee = trustee;
    }
    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }
    public Long getContractCategoryId() {
        return contractCategoryId;
    }

    public void setContractCategoryId(Long contractCategoryId) {
        this.contractCategoryId = contractCategoryId;
    }
    public String getContractCategoryName() {
        return contractCategoryName;
    }

    public void setContractCategoryName(String contractCategoryName) {
        this.contractCategoryName = contractCategoryName;
    }
    public String getConstructionQuality() {
        return constructionQuality;
    }

    public void setConstructionQuality(String constructionQuality) {
        this.constructionQuality = constructionQuality;
    }
    public String getSafetyProduction() {
        return safetyProduction;
    }

    public void setSafetyProduction(String safetyProduction) {
        this.safetyProduction = safetyProduction;
    }
    public BigDecimal getIcImage() {
        return icImage;
    }

    public void setIcImage(BigDecimal icImage) {
        this.icImage = icImage;
    }
    public BigDecimal getUpPayment() {
        return upPayment;
    }

    public void setUpPayment(BigDecimal upPayment) {
        this.upPayment = upPayment;
    }
    public BigDecimal getRiskFund() {
        return riskFund;
    }

    public void setRiskFund(BigDecimal riskFund) {
        this.riskFund = riskFund;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getTurninBase() {
        return turninBase;
    }

    public void setTurninBase(BigDecimal turninBase) {
        this.turninBase = turninBase;
    }
    public BigDecimal getResponsibilityCost() {
        return responsibilityCost;
    }

    public void setResponsibilityCost(BigDecimal responsibilityCost) {
        this.responsibilityCost = responsibilityCost;
    }
    public BigDecimal getAllScale() {
        return allScale;
    }

    public void setAllScale(BigDecimal allScale) {
        this.allScale = allScale;
    }
    public BigDecimal getAmountPaid() {
        return amountPaid;
    }

    public void setAmountPaid(BigDecimal amountPaid) {
        this.amountPaid = amountPaid;
    }
    public BigDecimal getPreBid() {
        return preBid;
    }

    public void setPreBid(BigDecimal preBid) {
        this.preBid = preBid;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20220711.065154-36-sources.jar: com/ejianc/business/zjkjcost/manage/bean/BookEntity.java <==
package com.ejianc.business.zjkjcost.manage.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目目标管理责任书
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_manage_book")
public class BookEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目部id
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织Id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="project_location")
    private String projectLocation; // 工程地点
    @TableField(value="built_area")
    private BigDecimal builtArea; // 建筑面积
    @TableField(value="structural_style")
    private String structuralStyle; // 结构形式
    @TableField(value="project_scale")
    private String projectScale; // 项目规模
    @TableField(value="price_method")
    private String priceMethod; // 计价方式
    @TableField(value="quality_standard")
    private String qualityStandard; // 质量标准
    @TableField(value="start_date")
    private Date startDate; // 开工日期
    @TableField(value="end_date")
    private Date endDate; // 竣工日期
    @TableField(value="zb_contract_mny")
    private BigDecimal zbContractMny; // 总包合同额
    @TableField(value="zs_contract_mny")
    private BigDecimal zsContractMny; // 自施合同额
    @TableField(value="other_contract_mny")
    private BigDecimal otherContractMny; // 其他合同额(集成)
    @TableField(value="client")
    private String client; // 委托人
    @TableField(value="trustee")
    private String trustee; // 受托人
    @TableField(value="duration")
    private Integer duration; // 合同总工期
    @TableField(value="contract_category_id")
    private Long contractCategoryId; // 合同类别
    @TableField(value="contract_category_name")
    private String contractCategoryName; // 合同类别名称
    @TableField(value="construction_quality")
    private String constructionQuality; // 工程质量
    @TableField(value="safety_production")
    private String safetyProduction; // 安全生产
    @TableField(value="ic_image")
    private BigDecimal icImage; // IC形象
    @TableField(value="up_payment")
    private BigDecimal upPayment; // 上缴款
    @TableField(value="risk_fund")
    private BigDecimal riskFund; // 风险金预留
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="turnin_base")
    private BigDecimal turninBase; // 上缴基数(不含税收入)
    @TableField(value="responsibility_cost")
    private BigDecimal responsibilityCost; // 责任成本(不含税成本)
    @TableField(value="all_scale")
    private BigDecimal allScale; // 整体上缴比例(B值)
    @TableField(value="amount_paid")
    private BigDecimal amountPaid; // 上缴金额(暂定，随结算金额调整)
    @TableField(value="pre_bid")
    private BigDecimal preBid; // 标前(A值)(承接利润率)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="file_id")
    private Long fileId; // word合同编辑文件id


    public Long getFileId() {
        return fileId;
    }

    public void setFileId(Long fileId) {
        this.fileId = fileId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getProjectLocation() {
        return projectLocation;
    }

    public void setProjectLocation(String projectLocation) {
        this.projectLocation = projectLocation;
    }
    public BigDecimal getBuiltArea() {
        return builtArea;
    }

    public void setBuiltArea(BigDecimal builtArea) {
        this.builtArea = builtArea;
    }
    public String getStructuralStyle() {
        return structuralStyle;
    }

    public void setStructuralStyle(String structuralStyle) {
        this.structuralStyle = structuralStyle;
    }
    public String getProjectScale() {
        return projectScale;
    }

    public void setProjectScale(String projectScale) {
        this.projectScale = projectScale;
    }
    public String getPriceMethod() {
        return priceMethod;
    }

    public void setPriceMethod(String priceMethod) {
        this.priceMethod = priceMethod;
    }
    public String getQualityStandard() {
        return qualityStandard;
    }

    public void setQualityStandard(String qualityStandard) {
        this.qualityStandard = qualityStandard;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public BigDecimal getZbContractMny() {
        return zbContractMny;
    }

    public void setZbContractMny(BigDecimal zbContractMny) {
        this.zbContractMny = zbContractMny;
    }
    public BigDecimal getZsContractMny() {
        return zsContractMny;
    }

    public void setZsContractMny(BigDecimal zsContractMny) {
        this.zsContractMny = zsContractMny;
    }
    public BigDecimal getOtherContractMny() {
        return otherContractMny;
    }

    public void setOtherContractMny(BigDecimal otherContractMny) {
        this.otherContractMny = otherContractMny;
    }
    public String getClient() {
        return client;
    }

    public void setClient(String client) {
        this.client = client;
    }
    public String getTrustee() {
        return trustee;
    }

    public void setTrustee(String trustee) {
        this.trustee = trustee;
    }
    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }
    public Long getContractCategoryId() {
        return contractCategoryId;
    }

    public void setContractCategoryId(Long contractCategoryId) {
        this.contractCategoryId = contractCategoryId;
    }
    public String getContractCategoryName() {
        return contractCategoryName;
    }

    public void setContractCategoryName(String contractCategoryName) {
        this.contractCategoryName = contractCategoryName;
    }
    public String getConstructionQuality() {
        return constructionQuality;
    }

    public void setConstructionQuality(String constructionQuality) {
        this.constructionQuality = constructionQuality;
    }
    public String getSafetyProduction() {
        return safetyProduction;
    }

    public void setSafetyProduction(String safetyProduction) {
        this.safetyProduction = safetyProduction;
    }
    public BigDecimal getIcImage() {
        return icImage;
    }

    public void setIcImage(BigDecimal icImage) {
        this.icImage = icImage;
    }
    public BigDecimal getUpPayment() {
        return upPayment;
    }

    public void setUpPayment(BigDecimal upPayment) {
        this.upPayment = upPayment;
    }
    public BigDecimal getRiskFund() {
        return riskFund;
    }

    public void setRiskFund(BigDecimal riskFund) {
        this.riskFund = riskFund;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getTurninBase() {
        return turninBase;
    }

    public void setTurninBase(BigDecimal turninBase) {
        this.turninBase = turninBase;
    }
    public BigDecimal getResponsibilityCost() {
        return responsibilityCost;
    }

    public void setResponsibilityCost(BigDecimal responsibilityCost) {
        this.responsibilityCost = responsibilityCost;
    }
    public BigDecimal getAllScale() {
        return allScale;
    }

    public void setAllScale(BigDecimal allScale) {
        this.allScale = allScale;
    }
    public BigDecimal getAmountPaid() {
        return amountPaid;
    }

    public void setAmountPaid(BigDecimal amountPaid) {
        this.amountPaid = amountPaid;
    }
    public BigDecimal getPreBid() {
        return preBid;
    }

    public void setPreBid(BigDecimal preBid) {
        this.preBid = preBid;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
